# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from vplexapi.api_client import ApiClient


class AggregateApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_aggregates(self, uri, group_by, **kwargs):  # noqa: E501
        """Groups the resources at the given URI by the values of the provided fields and returns aggregated computations for each group   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_aggregates(uri, group_by, async=True)
        >>> result = thread.get()

        :param async bool
        :param str uri: URI of collection to aggregate (required)
        :param str group_by: Comma-separated list of fields to aggregate on (required)
        :return: Aggregates
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_aggregates_with_http_info(uri, group_by, **kwargs)  # noqa: E501
        else:
            (data) = self.get_aggregates_with_http_info(uri, group_by, **kwargs)  # noqa: E501
            return data

    def get_aggregates_with_http_info(self, uri, group_by, **kwargs):  # noqa: E501
        """Groups the resources at the given URI by the values of the provided fields and returns aggregated computations for each group   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_aggregates_with_http_info(uri, group_by, async=True)
        >>> result = thread.get()

        :param async bool
        :param str uri: URI of collection to aggregate (required)
        :param str group_by: Comma-separated list of fields to aggregate on (required)
        :return: Aggregates
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uri', 'group_by']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_aggregates" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uri' is set
        if ('uri' not in params or
                params['uri'] is None):
            raise ValueError("Missing the required parameter `uri` when calling `get_aggregates`")  # noqa: E501
        # verify the required parameter 'group_by' is set
        if ('group_by' not in params or
                params['group_by'] is None):
            raise ValueError("Missing the required parameter `group_by` when calling `get_aggregates`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'uri' in params:
            query_params.append(('uri', params['uri']))  # noqa: E501
        if 'group_by' in params:
            query_params.append(('group_by', params['group_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'jwtAuth']  # noqa: E501

        return self.api_client.call_api(
            '/aggregates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Aggregates',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.admin_state import AdminState  # noqa: F401,E501


class ClusterWitnessComponents(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'admin_state': 'AdminState',
        'diagnostic': 'str',
        'management_connectivity': 'str',
        'name': 'str',
        'operational_state': 'str'
    }

    attribute_map = {
        'admin_state': 'admin_state',
        'diagnostic': 'diagnostic',
        'management_connectivity': 'management_connectivity',
        'name': 'name',
        'operational_state': 'operational_state'
    }

    def __init__(self, admin_state=None, diagnostic=None, management_connectivity=None, name=None, operational_state=None):  # noqa: E501
        """ClusterWitnessComponents - a model defined in Swagger"""  # noqa: E501

        self._admin_state = None
        self._diagnostic = None
        self._management_connectivity = None
        self._name = None
        self._operational_state = None
        self.discriminator = None

        if admin_state is not None:
            self.admin_state = admin_state
        if diagnostic is not None:
            self.diagnostic = diagnostic
        if management_connectivity is not None:
            self.management_connectivity = management_connectivity
        if name is not None:
            self.name = name
        if operational_state is not None:
            self.operational_state = operational_state

    @property
    def admin_state(self):
        """Gets the admin_state of this ClusterWitnessComponents.  # noqa: E501


        :return: The admin_state of this ClusterWitnessComponents.  # noqa: E501
        :rtype: AdminState
        """
        return self._admin_state

    @admin_state.setter
    def admin_state(self, admin_state):
        """Sets the admin_state of this ClusterWitnessComponents.


        :param admin_state: The admin_state of this ClusterWitnessComponents.  # noqa: E501
        :type: AdminState
        """

        self._admin_state = admin_state

    @property
    def diagnostic(self):
        """Gets the diagnostic of this ClusterWitnessComponents.  # noqa: E501


        :return: The diagnostic of this ClusterWitnessComponents.  # noqa: E501
        :rtype: str
        """
        return self._diagnostic

    @diagnostic.setter
    def diagnostic(self, diagnostic):
        """Sets the diagnostic of this ClusterWitnessComponents.


        :param diagnostic: The diagnostic of this ClusterWitnessComponents.  # noqa: E501
        :type: str
        """

        self._diagnostic = diagnostic

    @property
    def management_connectivity(self):
        """Gets the management_connectivity of this ClusterWitnessComponents.  # noqa: E501


        :return: The management_connectivity of this ClusterWitnessComponents.  # noqa: E501
        :rtype: str
        """
        return self._management_connectivity

    @management_connectivity.setter
    def management_connectivity(self, management_connectivity):
        """Sets the management_connectivity of this ClusterWitnessComponents.


        :param management_connectivity: The management_connectivity of this ClusterWitnessComponents.  # noqa: E501
        :type: str
        """

        self._management_connectivity = management_connectivity

    @property
    def name(self):
        """Gets the name of this ClusterWitnessComponents.  # noqa: E501


        :return: The name of this ClusterWitnessComponents.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ClusterWitnessComponents.


        :param name: The name of this ClusterWitnessComponents.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_state(self):
        """Gets the operational_state of this ClusterWitnessComponents.  # noqa: E501


        :return: The operational_state of this ClusterWitnessComponents.  # noqa: E501
        :rtype: str
        """
        return self._operational_state

    @operational_state.setter
    def operational_state(self, operational_state):
        """Sets the operational_state of this ClusterWitnessComponents.


        :param operational_state: The operational_state of this ClusterWitnessComponents.  # noqa: E501
        :type: str
        """

        self._operational_state = operational_state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterWitnessComponents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.storage_view_virtual_volumes import StorageViewVirtualVolumes  # noqa: F401,E501


class StorageView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'operational_status': 'str',
        'initiators': 'list[str]',
        'virtual_volumes': 'list[StorageViewVirtualVolumes]',
        'ports': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'operational_status': 'operational_status',
        'initiators': 'initiators',
        'virtual_volumes': 'virtual_volumes',
        'ports': 'ports'
    }

    def __init__(self, name=None, operational_status=None, initiators=None, virtual_volumes=None, ports=None):  # noqa: E501
        """StorageView - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._operational_status = None
        self._initiators = None
        self._virtual_volumes = None
        self._ports = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if operational_status is not None:
            self.operational_status = operational_status
        if initiators is not None:
            self.initiators = initiators
        if virtual_volumes is not None:
            self.virtual_volumes = virtual_volumes
        if ports is not None:
            self.ports = ports

    @property
    def name(self):
        """Gets the name of this StorageView.  # noqa: E501


        :return: The name of this StorageView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StorageView.


        :param name: The name of this StorageView.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_status(self):
        """Gets the operational_status of this StorageView.  # noqa: E501


        :return: The operational_status of this StorageView.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this StorageView.


        :param operational_status: The operational_status of this StorageView.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def initiators(self):
        """Gets the initiators of this StorageView.  # noqa: E501


        :return: The initiators of this StorageView.  # noqa: E501
        :rtype: list[str]
        """
        return self._initiators

    @initiators.setter
    def initiators(self, initiators):
        """Sets the initiators of this StorageView.


        :param initiators: The initiators of this StorageView.  # noqa: E501
        :type: list[str]
        """

        self._initiators = initiators

    @property
    def virtual_volumes(self):
        """Gets the virtual_volumes of this StorageView.  # noqa: E501


        :return: The virtual_volumes of this StorageView.  # noqa: E501
        :rtype: list[StorageViewVirtualVolumes]
        """
        return self._virtual_volumes

    @virtual_volumes.setter
    def virtual_volumes(self, virtual_volumes):
        """Sets the virtual_volumes of this StorageView.


        :param virtual_volumes: The virtual_volumes of this StorageView.  # noqa: E501
        :type: list[StorageViewVirtualVolumes]
        """

        self._virtual_volumes = virtual_volumes

    @property
    def ports(self):
        """Gets the ports of this StorageView.  # noqa: E501


        :return: The ports of this StorageView.  # noqa: E501
        :rtype: list[str]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this StorageView.


        :param ports: The ports of this StorageView.  # noqa: E501
        :type: list[str]
        """

        self._ports = ports

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageView):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.operational_status import OperationalStatus  # noqa: F401,E501
from vplexapi.models.role import Role  # noqa: F401,E501
from vplexapi.models.status import Status  # noqa: F401,E501


class DirectorPort(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'address': 'str',
        'status': 'Status',
        'operational_status': 'OperationalStatus',
        'role': 'Role',
        'enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'address': 'address',
        'status': 'status',
        'operational_status': 'operational_status',
        'role': 'role',
        'enabled': 'enabled'
    }

    def __init__(self, name=None, address=None, status=None, operational_status=None, role=None, enabled=None):  # noqa: E501
        """DirectorPort - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._address = None
        self._status = None
        self._operational_status = None
        self._role = None
        self._enabled = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if address is not None:
            self.address = address
        if status is not None:
            self.status = status
        if operational_status is not None:
            self.operational_status = operational_status
        if role is not None:
            self.role = role
        if enabled is not None:
            self.enabled = enabled

    @property
    def name(self):
        """Gets the name of this DirectorPort.  # noqa: E501


        :return: The name of this DirectorPort.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DirectorPort.


        :param name: The name of this DirectorPort.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def address(self):
        """Gets the address of this DirectorPort.  # noqa: E501


        :return: The address of this DirectorPort.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this DirectorPort.


        :param address: The address of this DirectorPort.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def status(self):
        """Gets the status of this DirectorPort.  # noqa: E501


        :return: The status of this DirectorPort.  # noqa: E501
        :rtype: Status
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DirectorPort.


        :param status: The status of this DirectorPort.  # noqa: E501
        :type: Status
        """

        self._status = status

    @property
    def operational_status(self):
        """Gets the operational_status of this DirectorPort.  # noqa: E501


        :return: The operational_status of this DirectorPort.  # noqa: E501
        :rtype: OperationalStatus
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this DirectorPort.


        :param operational_status: The operational_status of this DirectorPort.  # noqa: E501
        :type: OperationalStatus
        """

        self._operational_status = operational_status

    @property
    def role(self):
        """Gets the role of this DirectorPort.  # noqa: E501


        :return: The role of this DirectorPort.  # noqa: E501
        :rtype: Role
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this DirectorPort.


        :param role: The role of this DirectorPort.  # noqa: E501
        :type: Role
        """

        self._role = role

    @property
    def enabled(self):
        """Gets the enabled of this DirectorPort.  # noqa: E501


        :return: The enabled of this DirectorPort.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DirectorPort.


        :param enabled: The enabled of this DirectorPort.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DirectorPort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PortExports(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lun': 'str',
        'view': 'str',
        'volume': 'str',
        'status': 'str'
    }

    attribute_map = {
        'lun': 'lun',
        'view': 'view',
        'volume': 'volume',
        'status': 'status'
    }

    def __init__(self, lun=None, view=None, volume=None, status=None):  # noqa: E501
        """PortExports - a model defined in Swagger"""  # noqa: E501

        self._lun = None
        self._view = None
        self._volume = None
        self._status = None
        self.discriminator = None

        if lun is not None:
            self.lun = lun
        if view is not None:
            self.view = view
        if volume is not None:
            self.volume = volume
        if status is not None:
            self.status = status

    @property
    def lun(self):
        """Gets the lun of this PortExports.  # noqa: E501


        :return: The lun of this PortExports.  # noqa: E501
        :rtype: str
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this PortExports.


        :param lun: The lun of this PortExports.  # noqa: E501
        :type: str
        """

        self._lun = lun

    @property
    def view(self):
        """Gets the view of this PortExports.  # noqa: E501


        :return: The view of this PortExports.  # noqa: E501
        :rtype: str
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this PortExports.


        :param view: The view of this PortExports.  # noqa: E501
        :type: str
        """

        self._view = view

    @property
    def volume(self):
        """Gets the volume of this PortExports.  # noqa: E501


        :return: The volume of this PortExports.  # noqa: E501
        :rtype: str
        """
        return self._volume

    @volume.setter
    def volume(self, volume):
        """Sets the volume of this PortExports.


        :param volume: The volume of this PortExports.  # noqa: E501
        :type: str
        """

        self._volume = volume

    @property
    def status(self):
        """Gets the status of this PortExports.  # noqa: E501


        :return: The status of this PortExports.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PortExports.


        :param status: The status of this PortExports.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortExports):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RegisterPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'port_wwn': 'str',
        'iscsi_name': 'str',
        'port_name': 'str',
        'node_wwn': 'str',
        'type': 'str'
    }

    attribute_map = {
        'port_wwn': 'port_wwn',
        'iscsi_name': 'iscsi_name',
        'port_name': 'port_name',
        'node_wwn': 'node_wwn',
        'type': 'type'
    }

    def __init__(self, port_wwn=None, iscsi_name=None, port_name=None, node_wwn=None, type=None):  # noqa: E501
        """RegisterPayload - a model defined in Swagger"""  # noqa: E501

        self._port_wwn = None
        self._iscsi_name = None
        self._port_name = None
        self._node_wwn = None
        self._type = None
        self.discriminator = None

        if port_wwn is not None:
            self.port_wwn = port_wwn
        if iscsi_name is not None:
            self.iscsi_name = iscsi_name
        self.port_name = port_name
        if node_wwn is not None:
            self.node_wwn = node_wwn
        if type is not None:
            self.type = type

    @property
    def port_wwn(self):
        """Gets the port_wwn of this RegisterPayload.  # noqa: E501

        WWN of the port to register. Either port_wwn or iscsi_name should be provided.  # noqa: E501

        :return: The port_wwn of this RegisterPayload.  # noqa: E501
        :rtype: str
        """
        return self._port_wwn

    @port_wwn.setter
    def port_wwn(self, port_wwn):
        """Sets the port_wwn of this RegisterPayload.

        WWN of the port to register. Either port_wwn or iscsi_name should be provided.  # noqa: E501

        :param port_wwn: The port_wwn of this RegisterPayload.  # noqa: E501
        :type: str
        """

        self._port_wwn = port_wwn

    @property
    def iscsi_name(self):
        """Gets the iscsi_name of this RegisterPayload.  # noqa: E501

        ISCSI name of the port to register. Either port_wwn or iscsi_name should be provided.  # noqa: E501

        :return: The iscsi_name of this RegisterPayload.  # noqa: E501
        :rtype: str
        """
        return self._iscsi_name

    @iscsi_name.setter
    def iscsi_name(self, iscsi_name):
        """Sets the iscsi_name of this RegisterPayload.

        ISCSI name of the port to register. Either port_wwn or iscsi_name should be provided.  # noqa: E501

        :param iscsi_name: The iscsi_name of this RegisterPayload.  # noqa: E501
        :type: str
        """

        self._iscsi_name = iscsi_name

    @property
    def port_name(self):
        """Gets the port_name of this RegisterPayload.  # noqa: E501

        Provide a new name for the registered initiator port.  # noqa: E501

        :return: The port_name of this RegisterPayload.  # noqa: E501
        :rtype: str
        """
        return self._port_name

    @port_name.setter
    def port_name(self, port_name):
        """Sets the port_name of this RegisterPayload.

        Provide a new name for the registered initiator port.  # noqa: E501

        :param port_name: The port_name of this RegisterPayload.  # noqa: E501
        :type: str
        """
        if port_name is None:
            raise ValueError("Invalid value for `port_name`, must not be `None`")  # noqa: E501

        self._port_name = port_name

    @property
    def node_wwn(self):
        """Gets the node_wwn of this RegisterPayload.  # noqa: E501

        Provide node wwn for registering the port.  # noqa: E501

        :return: The node_wwn of this RegisterPayload.  # noqa: E501
        :rtype: str
        """
        return self._node_wwn

    @node_wwn.setter
    def node_wwn(self, node_wwn):
        """Sets the node_wwn of this RegisterPayload.

        Provide node wwn for registering the port.  # noqa: E501

        :param node_wwn: The node_wwn of this RegisterPayload.  # noqa: E501
        :type: str
        """

        self._node_wwn = node_wwn

    @property
    def type(self):
        """Gets the type of this RegisterPayload.  # noqa: E501

        Provide host type for registering the port.  # noqa: E501

        :return: The type of this RegisterPayload.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RegisterPayload.

        Provide host type for registering the port.  # noqa: E501

        :param type: The type of this RegisterPayload.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RegisterPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AmpPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'provider_name': 'str',
        'provider_type': 'str',
        'ip_address': 'str',
        'port': 'int',
        'user_name': 'str',
        'password': 'str',
        'use_ssl': 'bool'
    }

    attribute_map = {
        'provider_name': 'provider_name',
        'provider_type': 'provider_type',
        'ip_address': 'ip_address',
        'port': 'port',
        'user_name': 'user_name',
        'password': 'password',
        'use_ssl': 'use_ssl'
    }

    def __init__(self, provider_name=None, provider_type=None, ip_address=None, port=None, user_name=None, password=None, use_ssl=None):  # noqa: E501
        """AmpPayload - a model defined in Swagger"""  # noqa: E501

        self._provider_name = None
        self._provider_type = None
        self._ip_address = None
        self._port = None
        self._user_name = None
        self._password = None
        self._use_ssl = None
        self.discriminator = None

        self.provider_name = provider_name
        self.provider_type = provider_type
        self.ip_address = ip_address
        self.port = port
        self.user_name = user_name
        self.password = password
        self.use_ssl = use_ssl

    @property
    def provider_name(self):
        """Gets the provider_name of this AmpPayload.  # noqa: E501


        :return: The provider_name of this AmpPayload.  # noqa: E501
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """Sets the provider_name of this AmpPayload.


        :param provider_name: The provider_name of this AmpPayload.  # noqa: E501
        :type: str
        """
        if provider_name is None:
            raise ValueError("Invalid value for `provider_name`, must not be `None`")  # noqa: E501

        self._provider_name = provider_name

    @property
    def provider_type(self):
        """Gets the provider_type of this AmpPayload.  # noqa: E501


        :return: The provider_type of this AmpPayload.  # noqa: E501
        :rtype: str
        """
        return self._provider_type

    @provider_type.setter
    def provider_type(self, provider_type):
        """Sets the provider_type of this AmpPayload.


        :param provider_type: The provider_type of this AmpPayload.  # noqa: E501
        :type: str
        """
        if provider_type is None:
            raise ValueError("Invalid value for `provider_type`, must not be `None`")  # noqa: E501

        self._provider_type = provider_type

    @property
    def ip_address(self):
        """Gets the ip_address of this AmpPayload.  # noqa: E501


        :return: The ip_address of this AmpPayload.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this AmpPayload.


        :param ip_address: The ip_address of this AmpPayload.  # noqa: E501
        :type: str
        """
        if ip_address is None:
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def port(self):
        """Gets the port of this AmpPayload.  # noqa: E501


        :return: The port of this AmpPayload.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this AmpPayload.


        :param port: The port of this AmpPayload.  # noqa: E501
        :type: int
        """
        if port is None:
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def user_name(self):
        """Gets the user_name of this AmpPayload.  # noqa: E501


        :return: The user_name of this AmpPayload.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this AmpPayload.


        :param user_name: The user_name of this AmpPayload.  # noqa: E501
        :type: str
        """
        if user_name is None:
            raise ValueError("Invalid value for `user_name`, must not be `None`")  # noqa: E501

        self._user_name = user_name

    @property
    def password(self):
        """Gets the password of this AmpPayload.  # noqa: E501


        :return: The password of this AmpPayload.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this AmpPayload.


        :param password: The password of this AmpPayload.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def use_ssl(self):
        """Gets the use_ssl of this AmpPayload.  # noqa: E501


        :return: The use_ssl of this AmpPayload.  # noqa: E501
        :rtype: bool
        """
        return self._use_ssl

    @use_ssl.setter
    def use_ssl(self, use_ssl):
        """Sets the use_ssl of this AmpPayload.


        :param use_ssl: The use_ssl of this AmpPayload.  # noqa: E501
        :type: bool
        """
        if use_ssl is None:
            raise ValueError("Invalid value for `use_ssl`, must not be `None`")  # noqa: E501

        self._use_ssl = use_ssl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AmpPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DistributedDevicePayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'primary_leg': 'str',
        'secondary_leg': 'str',
        'rule_set': 'str',
        'sync': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'primary_leg': 'primary_leg',
        'secondary_leg': 'secondary_leg',
        'rule_set': 'rule_set',
        'sync': 'sync'
    }

    def __init__(self, name=None, primary_leg=None, secondary_leg=None, rule_set=None, sync=None):  # noqa: E501
        """DistributedDevicePayload - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._primary_leg = None
        self._secondary_leg = None
        self._rule_set = None
        self._sync = None
        self.discriminator = None

        self.name = name
        self.primary_leg = primary_leg
        self.secondary_leg = secondary_leg
        if rule_set is not None:
            self.rule_set = rule_set
        if sync is not None:
            self.sync = sync

    @property
    def name(self):
        """Gets the name of this DistributedDevicePayload.  # noqa: E501


        :return: The name of this DistributedDevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DistributedDevicePayload.


        :param name: The name of this DistributedDevicePayload.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def primary_leg(self):
        """Gets the primary_leg of this DistributedDevicePayload.  # noqa: E501


        :return: The primary_leg of this DistributedDevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._primary_leg

    @primary_leg.setter
    def primary_leg(self, primary_leg):
        """Sets the primary_leg of this DistributedDevicePayload.


        :param primary_leg: The primary_leg of this DistributedDevicePayload.  # noqa: E501
        :type: str
        """
        if primary_leg is None:
            raise ValueError("Invalid value for `primary_leg`, must not be `None`")  # noqa: E501

        self._primary_leg = primary_leg

    @property
    def secondary_leg(self):
        """Gets the secondary_leg of this DistributedDevicePayload.  # noqa: E501


        :return: The secondary_leg of this DistributedDevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._secondary_leg

    @secondary_leg.setter
    def secondary_leg(self, secondary_leg):
        """Sets the secondary_leg of this DistributedDevicePayload.


        :param secondary_leg: The secondary_leg of this DistributedDevicePayload.  # noqa: E501
        :type: str
        """
        if secondary_leg is None:
            raise ValueError("Invalid value for `secondary_leg`, must not be `None`")  # noqa: E501

        self._secondary_leg = secondary_leg

    @property
    def rule_set(self):
        """Gets the rule_set of this DistributedDevicePayload.  # noqa: E501


        :return: The rule_set of this DistributedDevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._rule_set

    @rule_set.setter
    def rule_set(self, rule_set):
        """Sets the rule_set of this DistributedDevicePayload.


        :param rule_set: The rule_set of this DistributedDevicePayload.  # noqa: E501
        :type: str
        """

        self._rule_set = rule_set

    @property
    def sync(self):
        """Gets the sync of this DistributedDevicePayload.  # noqa: E501


        :return: The sync of this DistributedDevicePayload.  # noqa: E501
        :rtype: bool
        """
        return self._sync

    @sync.setter
    def sync(self, sync):
        """Sets the sync of this DistributedDevicePayload.


        :param sync: The sync of this DistributedDevicePayload.  # noqa: E501
        :type: bool
        """

        self._sync = sync

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DistributedDevicePayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class VirtualVolumeExpandPayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'spare_storage': 'str',
        'skip_init': 'bool'
    }

    attribute_map = {
        'spare_storage': 'spare_storage',
        'skip_init': 'skip_init'
    }

    def __init__(self, spare_storage=None, skip_init=None):  # noqa: E501
        """VirtualVolumeExpandPayload - a model defined in Swagger"""  # noqa: E501

        self._spare_storage = None
        self._skip_init = None
        self.discriminator = None

        if spare_storage is not None:
            self.spare_storage = spare_storage
        if skip_init is not None:
            self.skip_init = skip_init

    @property
    def spare_storage(self):
        """Gets the spare_storage of this VirtualVolumeExpandPayload.  # noqa: E501

        Specifies the target device or extent that will be concatenated to the supporting storage. It shouldn't have a virtual-volume on top of it.  # noqa: E501

        :return: The spare_storage of this VirtualVolumeExpandPayload.  # noqa: E501
        :rtype: str
        """
        return self._spare_storage

    @spare_storage.setter
    def spare_storage(self, spare_storage):
        """Sets the spare_storage of this VirtualVolumeExpandPayload.

        Specifies the target device or extent that will be concatenated to the supporting storage. It shouldn't have a virtual-volume on top of it.  # noqa: E501

        :param spare_storage: The spare_storage of this VirtualVolumeExpandPayload.  # noqa: E501
        :type: str
        """

        self._spare_storage = spare_storage

    @property
    def skip_init(self):
        """Gets the skip_init of this VirtualVolumeExpandPayload.  # noqa: E501

        If skip_init is true the blocks of the expanded space will NOT be initialized to ensure single-disk semantics. This option should only be used under very specific circumstances, such as part of the recovery procedure after restoring metadata from backup.  # noqa: E501

        :return: The skip_init of this VirtualVolumeExpandPayload.  # noqa: E501
        :rtype: bool
        """
        return self._skip_init

    @skip_init.setter
    def skip_init(self, skip_init):
        """Sets the skip_init of this VirtualVolumeExpandPayload.

        If skip_init is true the blocks of the expanded space will NOT be initialized to ensure single-disk semantics. This option should only be used under very specific circumstances, such as part of the recovery procedure after restoring metadata from backup.  # noqa: E501

        :param skip_init: The skip_init of this VirtualVolumeExpandPayload.  # noqa: E501
        :type: bool
        """

        self._skip_init = skip_init

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VirtualVolumeExpandPayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Monitors(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'ownership': 'bool',
        'collecting_data': 'bool',
        'period': 'float',
        'average_period': 'float',
        'idle_for': 'float',
        'bucket_min': 'float',
        'bucket_max': 'float',
        'bucket_width': 'float',
        'bucket_count': 'float',
        'statistics': 'object',
        'firmware_id': 'float',
        'targets': 'list[str]',
        'version': 'str',
        'timestamp': 'str'
    }

    attribute_map = {
        'name': 'name',
        'ownership': 'ownership',
        'collecting_data': 'collecting_data',
        'period': 'period',
        'average_period': 'average_period',
        'idle_for': 'idle_for',
        'bucket_min': 'bucket_min',
        'bucket_max': 'bucket_max',
        'bucket_width': 'bucket_width',
        'bucket_count': 'bucket_count',
        'statistics': 'statistics',
        'firmware_id': 'firmware_id',
        'targets': 'targets',
        'version': 'version',
        'timestamp': 'timestamp'
    }

    def __init__(self, name=None, ownership=None, collecting_data=None, period=None, average_period=None, idle_for=None, bucket_min=None, bucket_max=None, bucket_width=None, bucket_count=None, statistics=None, firmware_id=None, targets=None, version=None, timestamp=None):  # noqa: E501
        """Monitors - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._ownership = None
        self._collecting_data = None
        self._period = None
        self._average_period = None
        self._idle_for = None
        self._bucket_min = None
        self._bucket_max = None
        self._bucket_width = None
        self._bucket_count = None
        self._statistics = None
        self._firmware_id = None
        self._targets = None
        self._version = None
        self._timestamp = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if ownership is not None:
            self.ownership = ownership
        if collecting_data is not None:
            self.collecting_data = collecting_data
        if period is not None:
            self.period = period
        if average_period is not None:
            self.average_period = average_period
        if idle_for is not None:
            self.idle_for = idle_for
        if bucket_min is not None:
            self.bucket_min = bucket_min
        if bucket_max is not None:
            self.bucket_max = bucket_max
        if bucket_width is not None:
            self.bucket_width = bucket_width
        if bucket_count is not None:
            self.bucket_count = bucket_count
        if statistics is not None:
            self.statistics = statistics
        if firmware_id is not None:
            self.firmware_id = firmware_id
        if targets is not None:
            self.targets = targets
        if version is not None:
            self.version = version
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def name(self):
        """Gets the name of this Monitors.  # noqa: E501


        :return: The name of this Monitors.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Monitors.


        :param name: The name of this Monitors.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def ownership(self):
        """Gets the ownership of this Monitors.  # noqa: E501


        :return: The ownership of this Monitors.  # noqa: E501
        :rtype: bool
        """
        return self._ownership

    @ownership.setter
    def ownership(self, ownership):
        """Sets the ownership of this Monitors.


        :param ownership: The ownership of this Monitors.  # noqa: E501
        :type: bool
        """

        self._ownership = ownership

    @property
    def collecting_data(self):
        """Gets the collecting_data of this Monitors.  # noqa: E501


        :return: The collecting_data of this Monitors.  # noqa: E501
        :rtype: bool
        """
        return self._collecting_data

    @collecting_data.setter
    def collecting_data(self, collecting_data):
        """Sets the collecting_data of this Monitors.


        :param collecting_data: The collecting_data of this Monitors.  # noqa: E501
        :type: bool
        """

        self._collecting_data = collecting_data

    @property
    def period(self):
        """Gets the period of this Monitors.  # noqa: E501


        :return: The period of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this Monitors.


        :param period: The period of this Monitors.  # noqa: E501
        :type: float
        """

        self._period = period

    @property
    def average_period(self):
        """Gets the average_period of this Monitors.  # noqa: E501


        :return: The average_period of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._average_period

    @average_period.setter
    def average_period(self, average_period):
        """Sets the average_period of this Monitors.


        :param average_period: The average_period of this Monitors.  # noqa: E501
        :type: float
        """

        self._average_period = average_period

    @property
    def idle_for(self):
        """Gets the idle_for of this Monitors.  # noqa: E501


        :return: The idle_for of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._idle_for

    @idle_for.setter
    def idle_for(self, idle_for):
        """Sets the idle_for of this Monitors.


        :param idle_for: The idle_for of this Monitors.  # noqa: E501
        :type: float
        """

        self._idle_for = idle_for

    @property
    def bucket_min(self):
        """Gets the bucket_min of this Monitors.  # noqa: E501


        :return: The bucket_min of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._bucket_min

    @bucket_min.setter
    def bucket_min(self, bucket_min):
        """Sets the bucket_min of this Monitors.


        :param bucket_min: The bucket_min of this Monitors.  # noqa: E501
        :type: float
        """

        self._bucket_min = bucket_min

    @property
    def bucket_max(self):
        """Gets the bucket_max of this Monitors.  # noqa: E501


        :return: The bucket_max of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._bucket_max

    @bucket_max.setter
    def bucket_max(self, bucket_max):
        """Sets the bucket_max of this Monitors.


        :param bucket_max: The bucket_max of this Monitors.  # noqa: E501
        :type: float
        """

        self._bucket_max = bucket_max

    @property
    def bucket_width(self):
        """Gets the bucket_width of this Monitors.  # noqa: E501


        :return: The bucket_width of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._bucket_width

    @bucket_width.setter
    def bucket_width(self, bucket_width):
        """Sets the bucket_width of this Monitors.


        :param bucket_width: The bucket_width of this Monitors.  # noqa: E501
        :type: float
        """

        self._bucket_width = bucket_width

    @property
    def bucket_count(self):
        """Gets the bucket_count of this Monitors.  # noqa: E501


        :return: The bucket_count of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._bucket_count

    @bucket_count.setter
    def bucket_count(self, bucket_count):
        """Sets the bucket_count of this Monitors.


        :param bucket_count: The bucket_count of this Monitors.  # noqa: E501
        :type: float
        """

        self._bucket_count = bucket_count

    @property
    def statistics(self):
        """Gets the statistics of this Monitors.  # noqa: E501


        :return: The statistics of this Monitors.  # noqa: E501
        :rtype: object
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """Sets the statistics of this Monitors.


        :param statistics: The statistics of this Monitors.  # noqa: E501
        :type: object
        """

        self._statistics = statistics

    @property
    def firmware_id(self):
        """Gets the firmware_id of this Monitors.  # noqa: E501


        :return: The firmware_id of this Monitors.  # noqa: E501
        :rtype: float
        """
        return self._firmware_id

    @firmware_id.setter
    def firmware_id(self, firmware_id):
        """Sets the firmware_id of this Monitors.


        :param firmware_id: The firmware_id of this Monitors.  # noqa: E501
        :type: float
        """

        self._firmware_id = firmware_id

    @property
    def targets(self):
        """Gets the targets of this Monitors.  # noqa: E501


        :return: The targets of this Monitors.  # noqa: E501
        :rtype: list[str]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """Sets the targets of this Monitors.


        :param targets: The targets of this Monitors.  # noqa: E501
        :type: list[str]
        """

        self._targets = targets

    @property
    def version(self):
        """Gets the version of this Monitors.  # noqa: E501


        :return: The version of this Monitors.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Monitors.


        :param version: The version of this Monitors.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def timestamp(self):
        """Gets the timestamp of this Monitors.  # noqa: E501


        :return: The timestamp of this Monitors.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Monitors.


        :param timestamp: The timestamp of this Monitors.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Monitors):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicePayload(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'secondary_legs': 'list[str]',
        'geometry': 'str',
        'primary_leg': 'str',
        'stripe_depth': 'str'
    }

    attribute_map = {
        'name': 'name',
        'secondary_legs': 'secondary_legs',
        'geometry': 'geometry',
        'primary_leg': 'primary_leg',
        'stripe_depth': 'stripe_depth'
    }

    def __init__(self, name=None, secondary_legs=None, geometry=None, primary_leg=None, stripe_depth=None):  # noqa: E501
        """DevicePayload - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._secondary_legs = None
        self._geometry = None
        self._primary_leg = None
        self._stripe_depth = None
        self.discriminator = None

        self.name = name
        if secondary_legs is not None:
            self.secondary_legs = secondary_legs
        self.geometry = geometry
        self.primary_leg = primary_leg
        if stripe_depth is not None:
            self.stripe_depth = stripe_depth

    @property
    def name(self):
        """Gets the name of this DevicePayload.  # noqa: E501


        :return: The name of this DevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DevicePayload.


        :param name: The name of this DevicePayload.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def secondary_legs(self):
        """Gets the secondary_legs of this DevicePayload.  # noqa: E501


        :return: The secondary_legs of this DevicePayload.  # noqa: E501
        :rtype: list[str]
        """
        return self._secondary_legs

    @secondary_legs.setter
    def secondary_legs(self, secondary_legs):
        """Sets the secondary_legs of this DevicePayload.


        :param secondary_legs: The secondary_legs of this DevicePayload.  # noqa: E501
        :type: list[str]
        """

        self._secondary_legs = secondary_legs

    @property
    def geometry(self):
        """Gets the geometry of this DevicePayload.  # noqa: E501

        Geometry for the new device. Valid values are raid-0, raid-1, or raid-c.  # noqa: E501

        :return: The geometry of this DevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._geometry

    @geometry.setter
    def geometry(self, geometry):
        """Sets the geometry of this DevicePayload.

        Geometry for the new device. Valid values are raid-0, raid-1, or raid-c.  # noqa: E501

        :param geometry: The geometry of this DevicePayload.  # noqa: E501
        :type: str
        """
        if geometry is None:
            raise ValueError("Invalid value for `geometry`, must not be `None`")  # noqa: E501

        self._geometry = geometry

    @property
    def primary_leg(self):
        """Gets the primary_leg of this DevicePayload.  # noqa: E501


        :return: The primary_leg of this DevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._primary_leg

    @primary_leg.setter
    def primary_leg(self, primary_leg):
        """Sets the primary_leg of this DevicePayload.


        :param primary_leg: The primary_leg of this DevicePayload.  # noqa: E501
        :type: str
        """
        if primary_leg is None:
            raise ValueError("Invalid value for `primary_leg`, must not be `None`")  # noqa: E501

        self._primary_leg = primary_leg

    @property
    def stripe_depth(self):
        """Gets the stripe_depth of this DevicePayload.  # noqa: E501

        Required only if geometry is raid-0.  # noqa: E501

        :return: The stripe_depth of this DevicePayload.  # noqa: E501
        :rtype: str
        """
        return self._stripe_depth

    @stripe_depth.setter
    def stripe_depth(self, stripe_depth):
        """Sets the stripe_depth of this DevicePayload.

        Required only if geometry is raid-0.  # noqa: E501

        :param stripe_depth: The stripe_depth of this DevicePayload.  # noqa: E501
        :type: str
        """

        self._stripe_depth = stripe_depth

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePayload):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ConnectivityStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    OK = "ok"
    DEGRADED = "degraded"
    ERROR = "error"
    INITIAL = "initial"
    REPAIRABLE = "repairable"
    UNKNOWN = "unknown"

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """ConnectivityStatus - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectivityStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vplexapi.models.consistency_group_operational_status import ConsistencyGroupOperationalStatus  # noqa: F401,E501


class ConsistencyGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'operational_status': 'list[ConsistencyGroupOperationalStatus]',
        'active_clusters': 'list[str]',
        'passive_clusters': 'list[str]',
        'detach_rule': 'object',
        'auto_resume_at_loser': 'bool',
        'cache_mode': 'str',
        'read_only': 'bool',
        'storage_at_clusters': 'list[str]',
        'virtual_volumes': 'list[str]',
        'visibility': 'list[str]',
        'recoverpoint_enabled': 'bool',
        'recoverpoint': 'object'
    }

    attribute_map = {
        'name': 'name',
        'operational_status': 'operational_status',
        'active_clusters': 'active_clusters',
        'passive_clusters': 'passive_clusters',
        'detach_rule': 'detach_rule',
        'auto_resume_at_loser': 'auto_resume_at_loser',
        'cache_mode': 'cache_mode',
        'read_only': 'read_only',
        'storage_at_clusters': 'storage_at_clusters',
        'virtual_volumes': 'virtual_volumes',
        'visibility': 'visibility',
        'recoverpoint_enabled': 'recoverpoint_enabled',
        'recoverpoint': 'recoverpoint'
    }

    def __init__(self, name=None, operational_status=None, active_clusters=None, passive_clusters=None, detach_rule=None, auto_resume_at_loser=None, cache_mode=None, read_only=None, storage_at_clusters=None, virtual_volumes=None, visibility=None, recoverpoint_enabled=None, recoverpoint=None):  # noqa: E501
        """ConsistencyGroup - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._operational_status = None
        self._active_clusters = None
        self._passive_clusters = None
        self._detach_rule = None
        self._auto_resume_at_loser = None
        self._cache_mode = None
        self._read_only = None
        self._storage_at_clusters = None
        self._virtual_volumes = None
        self._visibility = None
        self._recoverpoint_enabled = None
        self._recoverpoint = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if operational_status is not None:
            self.operational_status = operational_status
        if active_clusters is not None:
            self.active_clusters = active_clusters
        if passive_clusters is not None:
            self.passive_clusters = passive_clusters
        if detach_rule is not None:
            self.detach_rule = detach_rule
        if auto_resume_at_loser is not None:
            self.auto_resume_at_loser = auto_resume_at_loser
        if cache_mode is not None:
            self.cache_mode = cache_mode
        if read_only is not None:
            self.read_only = read_only
        if storage_at_clusters is not None:
            self.storage_at_clusters = storage_at_clusters
        if virtual_volumes is not None:
            self.virtual_volumes = virtual_volumes
        if visibility is not None:
            self.visibility = visibility
        if recoverpoint_enabled is not None:
            self.recoverpoint_enabled = recoverpoint_enabled
        if recoverpoint is not None:
            self.recoverpoint = recoverpoint

    @property
    def name(self):
        """Gets the name of this ConsistencyGroup.  # noqa: E501


        :return: The name of this ConsistencyGroup.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConsistencyGroup.


        :param name: The name of this ConsistencyGroup.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_status(self):
        """Gets the operational_status of this ConsistencyGroup.  # noqa: E501


        :return: The operational_status of this ConsistencyGroup.  # noqa: E501
        :rtype: list[ConsistencyGroupOperationalStatus]
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this ConsistencyGroup.


        :param operational_status: The operational_status of this ConsistencyGroup.  # noqa: E501
        :type: list[ConsistencyGroupOperationalStatus]
        """

        self._operational_status = operational_status

    @property
    def active_clusters(self):
        """Gets the active_clusters of this ConsistencyGroup.  # noqa: E501


        :return: The active_clusters of this ConsistencyGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._active_clusters

    @active_clusters.setter
    def active_clusters(self, active_clusters):
        """Sets the active_clusters of this ConsistencyGroup.


        :param active_clusters: The active_clusters of this ConsistencyGroup.  # noqa: E501
        :type: list[str]
        """

        self._active_clusters = active_clusters

    @property
    def passive_clusters(self):
        """Gets the passive_clusters of this ConsistencyGroup.  # noqa: E501


        :return: The passive_clusters of this ConsistencyGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._passive_clusters

    @passive_clusters.setter
    def passive_clusters(self, passive_clusters):
        """Sets the passive_clusters of this ConsistencyGroup.


        :param passive_clusters: The passive_clusters of this ConsistencyGroup.  # noqa: E501
        :type: list[str]
        """

        self._passive_clusters = passive_clusters

    @property
    def detach_rule(self):
        """Gets the detach_rule of this ConsistencyGroup.  # noqa: E501


        :return: The detach_rule of this ConsistencyGroup.  # noqa: E501
        :rtype: object
        """
        return self._detach_rule

    @detach_rule.setter
    def detach_rule(self, detach_rule):
        """Sets the detach_rule of this ConsistencyGroup.


        :param detach_rule: The detach_rule of this ConsistencyGroup.  # noqa: E501
        :type: object
        """

        self._detach_rule = detach_rule

    @property
    def auto_resume_at_loser(self):
        """Gets the auto_resume_at_loser of this ConsistencyGroup.  # noqa: E501


        :return: The auto_resume_at_loser of this ConsistencyGroup.  # noqa: E501
        :rtype: bool
        """
        return self._auto_resume_at_loser

    @auto_resume_at_loser.setter
    def auto_resume_at_loser(self, auto_resume_at_loser):
        """Sets the auto_resume_at_loser of this ConsistencyGroup.


        :param auto_resume_at_loser: The auto_resume_at_loser of this ConsistencyGroup.  # noqa: E501
        :type: bool
        """

        self._auto_resume_at_loser = auto_resume_at_loser

    @property
    def cache_mode(self):
        """Gets the cache_mode of this ConsistencyGroup.  # noqa: E501


        :return: The cache_mode of this ConsistencyGroup.  # noqa: E501
        :rtype: str
        """
        return self._cache_mode

    @cache_mode.setter
    def cache_mode(self, cache_mode):
        """Sets the cache_mode of this ConsistencyGroup.


        :param cache_mode: The cache_mode of this ConsistencyGroup.  # noqa: E501
        :type: str
        """

        self._cache_mode = cache_mode

    @property
    def read_only(self):
        """Gets the read_only of this ConsistencyGroup.  # noqa: E501


        :return: The read_only of this ConsistencyGroup.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this ConsistencyGroup.


        :param read_only: The read_only of this ConsistencyGroup.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def storage_at_clusters(self):
        """Gets the storage_at_clusters of this ConsistencyGroup.  # noqa: E501


        :return: The storage_at_clusters of this ConsistencyGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_at_clusters

    @storage_at_clusters.setter
    def storage_at_clusters(self, storage_at_clusters):
        """Sets the storage_at_clusters of this ConsistencyGroup.


        :param storage_at_clusters: The storage_at_clusters of this ConsistencyGroup.  # noqa: E501
        :type: list[str]
        """

        self._storage_at_clusters = storage_at_clusters

    @property
    def virtual_volumes(self):
        """Gets the virtual_volumes of this ConsistencyGroup.  # noqa: E501


        :return: The virtual_volumes of this ConsistencyGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._virtual_volumes

    @virtual_volumes.setter
    def virtual_volumes(self, virtual_volumes):
        """Sets the virtual_volumes of this ConsistencyGroup.


        :param virtual_volumes: The virtual_volumes of this ConsistencyGroup.  # noqa: E501
        :type: list[str]
        """

        self._virtual_volumes = virtual_volumes

    @property
    def visibility(self):
        """Gets the visibility of this ConsistencyGroup.  # noqa: E501


        :return: The visibility of this ConsistencyGroup.  # noqa: E501
        :rtype: list[str]
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this ConsistencyGroup.


        :param visibility: The visibility of this ConsistencyGroup.  # noqa: E501
        :type: list[str]
        """

        self._visibility = visibility

    @property
    def recoverpoint_enabled(self):
        """Gets the recoverpoint_enabled of this ConsistencyGroup.  # noqa: E501


        :return: The recoverpoint_enabled of this ConsistencyGroup.  # noqa: E501
        :rtype: bool
        """
        return self._recoverpoint_enabled

    @recoverpoint_enabled.setter
    def recoverpoint_enabled(self, recoverpoint_enabled):
        """Sets the recoverpoint_enabled of this ConsistencyGroup.


        :param recoverpoint_enabled: The recoverpoint_enabled of this ConsistencyGroup.  # noqa: E501
        :type: bool
        """

        self._recoverpoint_enabled = recoverpoint_enabled

    @property
    def recoverpoint(self):
        """Gets the recoverpoint of this ConsistencyGroup.  # noqa: E501


        :return: The recoverpoint of this ConsistencyGroup.  # noqa: E501
        :rtype: object
        """
        return self._recoverpoint

    @recoverpoint.setter
    def recoverpoint(self, recoverpoint):
        """Sets the recoverpoint of this ConsistencyGroup.


        :param recoverpoint: The recoverpoint of this ConsistencyGroup.  # noqa: E501
        :type: object
        """

        self._recoverpoint = recoverpoint

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConsistencyGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Certificate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ip_address': 'str',
        'issued_to': 'str',
        'issued_by': 'str',
        'issued_on': 'datetime',
        'expires_on': 'datetime',
        'sha1': 'str',
        'md5': 'str',
        'encoded_certificate': 'str'
    }

    attribute_map = {
        'ip_address': 'ip_address',
        'issued_to': 'issued_to',
        'issued_by': 'issued_by',
        'issued_on': 'issued_on',
        'expires_on': 'expires_on',
        'sha1': 'SHA1',
        'md5': 'MD5',
        'encoded_certificate': 'encoded_certificate'
    }

    def __init__(self, ip_address=None, issued_to=None, issued_by=None, issued_on=None, expires_on=None, sha1=None, md5=None, encoded_certificate=None):  # noqa: E501
        """Certificate - a model defined in Swagger"""  # noqa: E501

        self._ip_address = None
        self._issued_to = None
        self._issued_by = None
        self._issued_on = None
        self._expires_on = None
        self._sha1 = None
        self._md5 = None
        self._encoded_certificate = None
        self.discriminator = None

        if ip_address is not None:
            self.ip_address = ip_address
        if issued_to is not None:
            self.issued_to = issued_to
        if issued_by is not None:
            self.issued_by = issued_by
        if issued_on is not None:
            self.issued_on = issued_on
        if expires_on is not None:
            self.expires_on = expires_on
        if sha1 is not None:
            self.sha1 = sha1
        if md5 is not None:
            self.md5 = md5
        if encoded_certificate is not None:
            self.encoded_certificate = encoded_certificate

    @property
    def ip_address(self):
        """Gets the ip_address of this Certificate.  # noqa: E501


        :return: The ip_address of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this Certificate.


        :param ip_address: The ip_address of this Certificate.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def issued_to(self):
        """Gets the issued_to of this Certificate.  # noqa: E501


        :return: The issued_to of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._issued_to

    @issued_to.setter
    def issued_to(self, issued_to):
        """Sets the issued_to of this Certificate.


        :param issued_to: The issued_to of this Certificate.  # noqa: E501
        :type: str
        """

        self._issued_to = issued_to

    @property
    def issued_by(self):
        """Gets the issued_by of this Certificate.  # noqa: E501


        :return: The issued_by of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._issued_by

    @issued_by.setter
    def issued_by(self, issued_by):
        """Sets the issued_by of this Certificate.


        :param issued_by: The issued_by of this Certificate.  # noqa: E501
        :type: str
        """

        self._issued_by = issued_by

    @property
    def issued_on(self):
        """Gets the issued_on of this Certificate.  # noqa: E501


        :return: The issued_on of this Certificate.  # noqa: E501
        :rtype: datetime
        """
        return self._issued_on

    @issued_on.setter
    def issued_on(self, issued_on):
        """Sets the issued_on of this Certificate.


        :param issued_on: The issued_on of this Certificate.  # noqa: E501
        :type: datetime
        """

        self._issued_on = issued_on

    @property
    def expires_on(self):
        """Gets the expires_on of this Certificate.  # noqa: E501


        :return: The expires_on of this Certificate.  # noqa: E501
        :rtype: datetime
        """
        return self._expires_on

    @expires_on.setter
    def expires_on(self, expires_on):
        """Sets the expires_on of this Certificate.


        :param expires_on: The expires_on of this Certificate.  # noqa: E501
        :type: datetime
        """

        self._expires_on = expires_on

    @property
    def sha1(self):
        """Gets the sha1 of this Certificate.  # noqa: E501


        :return: The sha1 of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this Certificate.


        :param sha1: The sha1 of this Certificate.  # noqa: E501
        :type: str
        """

        self._sha1 = sha1

    @property
    def md5(self):
        """Gets the md5 of this Certificate.  # noqa: E501


        :return: The md5 of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this Certificate.


        :param md5: The md5 of this Certificate.  # noqa: E501
        :type: str
        """

        self._md5 = md5

    @property
    def encoded_certificate(self):
        """Gets the encoded_certificate of this Certificate.  # noqa: E501


        :return: The encoded_certificate of this Certificate.  # noqa: E501
        :rtype: str
        """
        return self._encoded_certificate

    @encoded_certificate.setter
    def encoded_certificate(self, encoded_certificate):
        """Sets the encoded_certificate of this Certificate.


        :param encoded_certificate: The encoded_certificate of this Certificate.  # noqa: E501
        :type: str
        """

        self._encoded_certificate = encoded_certificate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Certificate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class VirtualVolume(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'operational_status': 'str',
        'health_state': 'str',
        'service_status': 'str',
        'block_count': 'int',
        'block_size': 'int',
        'capacity': 'int',
        'supporting_device': 'str',
        'expandable': 'bool',
        'expandable_capacity': 'int',
        'consistency_group': 'str',
        'vpd_id': 'str',
        'thin_enabled': 'str',
        'expansion_method': 'str',
        'expansion_status': 'str',
        'health_indications': 'list[str]',
        'initialization_status': 'str',
        'recoverpoint_protection_at': 'list[str]',
        'recoverpoint_usage': 'str',
        'storage_array_family': 'str',
        'system_id': 'str',
        'visibility': 'str',
        'locality': 'str'
    }

    attribute_map = {
        'name': 'name',
        'operational_status': 'operational_status',
        'health_state': 'health_state',
        'service_status': 'service_status',
        'block_count': 'block_count',
        'block_size': 'block_size',
        'capacity': 'capacity',
        'supporting_device': 'supporting_device',
        'expandable': 'expandable',
        'expandable_capacity': 'expandable_capacity',
        'consistency_group': 'consistency_group',
        'vpd_id': 'vpd_id',
        'thin_enabled': 'thin_enabled',
        'expansion_method': 'expansion_method',
        'expansion_status': 'expansion_status',
        'health_indications': 'health_indications',
        'initialization_status': 'initialization_status',
        'recoverpoint_protection_at': 'recoverpoint_protection_at',
        'recoverpoint_usage': 'recoverpoint_usage',
        'storage_array_family': 'storage_array_family',
        'system_id': 'system_id',
        'visibility': 'visibility',
        'locality': 'locality'
    }

    def __init__(self, name=None, operational_status=None, health_state=None, service_status=None, block_count=None, block_size=None, capacity=None, supporting_device=None, expandable=None, expandable_capacity=None, consistency_group=None, vpd_id=None, thin_enabled=None, expansion_method=None, expansion_status=None, health_indications=None, initialization_status=None, recoverpoint_protection_at=None, recoverpoint_usage=None, storage_array_family=None, system_id=None, visibility=None, locality=None):  # noqa: E501
        """VirtualVolume - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._operational_status = None
        self._health_state = None
        self._service_status = None
        self._block_count = None
        self._block_size = None
        self._capacity = None
        self._supporting_device = None
        self._expandable = None
        self._expandable_capacity = None
        self._consistency_group = None
        self._vpd_id = None
        self._thin_enabled = None
        self._expansion_method = None
        self._expansion_status = None
        self._health_indications = None
        self._initialization_status = None
        self._recoverpoint_protection_at = None
        self._recoverpoint_usage = None
        self._storage_array_family = None
        self._system_id = None
        self._visibility = None
        self._locality = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if operational_status is not None:
            self.operational_status = operational_status
        if health_state is not None:
            self.health_state = health_state
        if service_status is not None:
            self.service_status = service_status
        if block_count is not None:
            self.block_count = block_count
        if block_size is not None:
            self.block_size = block_size
        if capacity is not None:
            self.capacity = capacity
        if supporting_device is not None:
            self.supporting_device = supporting_device
        if expandable is not None:
            self.expandable = expandable
        if expandable_capacity is not None:
            self.expandable_capacity = expandable_capacity
        if consistency_group is not None:
            self.consistency_group = consistency_group
        if vpd_id is not None:
            self.vpd_id = vpd_id
        if thin_enabled is not None:
            self.thin_enabled = thin_enabled
        if expansion_method is not None:
            self.expansion_method = expansion_method
        if expansion_status is not None:
            self.expansion_status = expansion_status
        if health_indications is not None:
            self.health_indications = health_indications
        if initialization_status is not None:
            self.initialization_status = initialization_status
        if recoverpoint_protection_at is not None:
            self.recoverpoint_protection_at = recoverpoint_protection_at
        if recoverpoint_usage is not None:
            self.recoverpoint_usage = recoverpoint_usage
        if storage_array_family is not None:
            self.storage_array_family = storage_array_family
        if system_id is not None:
            self.system_id = system_id
        if visibility is not None:
            self.visibility = visibility
        if locality is not None:
            self.locality = locality

    @property
    def name(self):
        """Gets the name of this VirtualVolume.  # noqa: E501


        :return: The name of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VirtualVolume.


        :param name: The name of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operational_status(self):
        """Gets the operational_status of this VirtualVolume.  # noqa: E501


        :return: The operational_status of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._operational_status

    @operational_status.setter
    def operational_status(self, operational_status):
        """Sets the operational_status of this VirtualVolume.


        :param operational_status: The operational_status of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._operational_status = operational_status

    @property
    def health_state(self):
        """Gets the health_state of this VirtualVolume.  # noqa: E501


        :return: The health_state of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._health_state

    @health_state.setter
    def health_state(self, health_state):
        """Sets the health_state of this VirtualVolume.


        :param health_state: The health_state of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._health_state = health_state

    @property
    def service_status(self):
        """Gets the service_status of this VirtualVolume.  # noqa: E501


        :return: The service_status of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._service_status

    @service_status.setter
    def service_status(self, service_status):
        """Sets the service_status of this VirtualVolume.


        :param service_status: The service_status of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._service_status = service_status

    @property
    def block_count(self):
        """Gets the block_count of this VirtualVolume.  # noqa: E501


        :return: The block_count of this VirtualVolume.  # noqa: E501
        :rtype: int
        """
        return self._block_count

    @block_count.setter
    def block_count(self, block_count):
        """Sets the block_count of this VirtualVolume.


        :param block_count: The block_count of this VirtualVolume.  # noqa: E501
        :type: int
        """

        self._block_count = block_count

    @property
    def block_size(self):
        """Gets the block_size of this VirtualVolume.  # noqa: E501


        :return: The block_size of this VirtualVolume.  # noqa: E501
        :rtype: int
        """
        return self._block_size

    @block_size.setter
    def block_size(self, block_size):
        """Sets the block_size of this VirtualVolume.


        :param block_size: The block_size of this VirtualVolume.  # noqa: E501
        :type: int
        """

        self._block_size = block_size

    @property
    def capacity(self):
        """Gets the capacity of this VirtualVolume.  # noqa: E501


        :return: The capacity of this VirtualVolume.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this VirtualVolume.


        :param capacity: The capacity of this VirtualVolume.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def supporting_device(self):
        """Gets the supporting_device of this VirtualVolume.  # noqa: E501


        :return: The supporting_device of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._supporting_device

    @supporting_device.setter
    def supporting_device(self, supporting_device):
        """Sets the supporting_device of this VirtualVolume.


        :param supporting_device: The supporting_device of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._supporting_device = supporting_device

    @property
    def expandable(self):
        """Gets the expandable of this VirtualVolume.  # noqa: E501


        :return: The expandable of this VirtualVolume.  # noqa: E501
        :rtype: bool
        """
        return self._expandable

    @expandable.setter
    def expandable(self, expandable):
        """Sets the expandable of this VirtualVolume.


        :param expandable: The expandable of this VirtualVolume.  # noqa: E501
        :type: bool
        """

        self._expandable = expandable

    @property
    def expandable_capacity(self):
        """Gets the expandable_capacity of this VirtualVolume.  # noqa: E501


        :return: The expandable_capacity of this VirtualVolume.  # noqa: E501
        :rtype: int
        """
        return self._expandable_capacity

    @expandable_capacity.setter
    def expandable_capacity(self, expandable_capacity):
        """Sets the expandable_capacity of this VirtualVolume.


        :param expandable_capacity: The expandable_capacity of this VirtualVolume.  # noqa: E501
        :type: int
        """

        self._expandable_capacity = expandable_capacity

    @property
    def consistency_group(self):
        """Gets the consistency_group of this VirtualVolume.  # noqa: E501


        :return: The consistency_group of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._consistency_group

    @consistency_group.setter
    def consistency_group(self, consistency_group):
        """Sets the consistency_group of this VirtualVolume.


        :param consistency_group: The consistency_group of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._consistency_group = consistency_group

    @property
    def vpd_id(self):
        """Gets the vpd_id of this VirtualVolume.  # noqa: E501


        :return: The vpd_id of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._vpd_id

    @vpd_id.setter
    def vpd_id(self, vpd_id):
        """Sets the vpd_id of this VirtualVolume.


        :param vpd_id: The vpd_id of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._vpd_id = vpd_id

    @property
    def thin_enabled(self):
        """Gets the thin_enabled of this VirtualVolume.  # noqa: E501


        :return: The thin_enabled of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._thin_enabled

    @thin_enabled.setter
    def thin_enabled(self, thin_enabled):
        """Sets the thin_enabled of this VirtualVolume.


        :param thin_enabled: The thin_enabled of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._thin_enabled = thin_enabled

    @property
    def expansion_method(self):
        """Gets the expansion_method of this VirtualVolume.  # noqa: E501


        :return: The expansion_method of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._expansion_method

    @expansion_method.setter
    def expansion_method(self, expansion_method):
        """Sets the expansion_method of this VirtualVolume.


        :param expansion_method: The expansion_method of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._expansion_method = expansion_method

    @property
    def expansion_status(self):
        """Gets the expansion_status of this VirtualVolume.  # noqa: E501


        :return: The expansion_status of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._expansion_status

    @expansion_status.setter
    def expansion_status(self, expansion_status):
        """Sets the expansion_status of this VirtualVolume.


        :param expansion_status: The expansion_status of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._expansion_status = expansion_status

    @property
    def health_indications(self):
        """Gets the health_indications of this VirtualVolume.  # noqa: E501


        :return: The health_indications of this VirtualVolume.  # noqa: E501
        :rtype: list[str]
        """
        return self._health_indications

    @health_indications.setter
    def health_indications(self, health_indications):
        """Sets the health_indications of this VirtualVolume.


        :param health_indications: The health_indications of this VirtualVolume.  # noqa: E501
        :type: list[str]
        """

        self._health_indications = health_indications

    @property
    def initialization_status(self):
        """Gets the initialization_status of this VirtualVolume.  # noqa: E501


        :return: The initialization_status of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._initialization_status

    @initialization_status.setter
    def initialization_status(self, initialization_status):
        """Sets the initialization_status of this VirtualVolume.


        :param initialization_status: The initialization_status of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._initialization_status = initialization_status

    @property
    def recoverpoint_protection_at(self):
        """Gets the recoverpoint_protection_at of this VirtualVolume.  # noqa: E501


        :return: The recoverpoint_protection_at of this VirtualVolume.  # noqa: E501
        :rtype: list[str]
        """
        return self._recoverpoint_protection_at

    @recoverpoint_protection_at.setter
    def recoverpoint_protection_at(self, recoverpoint_protection_at):
        """Sets the recoverpoint_protection_at of this VirtualVolume.


        :param recoverpoint_protection_at: The recoverpoint_protection_at of this VirtualVolume.  # noqa: E501
        :type: list[str]
        """

        self._recoverpoint_protection_at = recoverpoint_protection_at

    @property
    def recoverpoint_usage(self):
        """Gets the recoverpoint_usage of this VirtualVolume.  # noqa: E501


        :return: The recoverpoint_usage of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._recoverpoint_usage

    @recoverpoint_usage.setter
    def recoverpoint_usage(self, recoverpoint_usage):
        """Sets the recoverpoint_usage of this VirtualVolume.


        :param recoverpoint_usage: The recoverpoint_usage of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._recoverpoint_usage = recoverpoint_usage

    @property
    def storage_array_family(self):
        """Gets the storage_array_family of this VirtualVolume.  # noqa: E501


        :return: The storage_array_family of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._storage_array_family

    @storage_array_family.setter
    def storage_array_family(self, storage_array_family):
        """Sets the storage_array_family of this VirtualVolume.


        :param storage_array_family: The storage_array_family of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._storage_array_family = storage_array_family

    @property
    def system_id(self):
        """Gets the system_id of this VirtualVolume.  # noqa: E501


        :return: The system_id of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._system_id

    @system_id.setter
    def system_id(self, system_id):
        """Sets the system_id of this VirtualVolume.


        :param system_id: The system_id of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._system_id = system_id

    @property
    def visibility(self):
        """Gets the visibility of this VirtualVolume.  # noqa: E501


        :return: The visibility of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """Sets the visibility of this VirtualVolume.


        :param visibility: The visibility of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._visibility = visibility

    @property
    def locality(self):
        """Gets the locality of this VirtualVolume.  # noqa: E501


        :return: The locality of this VirtualVolume.  # noqa: E501
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """Sets the locality of this VirtualVolume.


        :param locality: The locality of this VirtualVolume.  # noqa: E501
        :type: str
        """

        self._locality = locality

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VirtualVolume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class License(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'feature_name': 'str',
        'issuer': 'str',
        'issued_date': 'datetime',
        'expiry_date': 'datetime',
        'notice': 'str',
        'valid': 'str',
        'platform': 'str',
        'uom_code': 'str',
        'uom_name': 'str',
        'plc': 'str',
        'product_line': 'str',
        'capacity': 'float',
        'usage': 'float',
        'notification': 'str'
    }

    attribute_map = {
        'feature_name': 'feature_name',
        'issuer': 'issuer',
        'issued_date': 'issued_date',
        'expiry_date': 'expiry_date',
        'notice': 'notice',
        'valid': 'valid',
        'platform': 'platform',
        'uom_code': 'uom_code',
        'uom_name': 'uom_name',
        'plc': 'plc',
        'product_line': 'product_line',
        'capacity': 'capacity',
        'usage': 'usage',
        'notification': 'notification'
    }

    def __init__(self, feature_name=None, issuer=None, issued_date=None, expiry_date=None, notice=None, valid=None, platform=None, uom_code=None, uom_name=None, plc=None, product_line=None, capacity=None, usage=None, notification=None):  # noqa: E501
        """License - a model defined in Swagger"""  # noqa: E501

        self._feature_name = None
        self._issuer = None
        self._issued_date = None
        self._expiry_date = None
        self._notice = None
        self._valid = None
        self._platform = None
        self._uom_code = None
        self._uom_name = None
        self._plc = None
        self._product_line = None
        self._capacity = None
        self._usage = None
        self._notification = None
        self.discriminator = None

        self.feature_name = feature_name
        if issuer is not None:
            self.issuer = issuer
        if issued_date is not None:
            self.issued_date = issued_date
        if expiry_date is not None:
            self.expiry_date = expiry_date
        if notice is not None:
            self.notice = notice
        if valid is not None:
            self.valid = valid
        if platform is not None:
            self.platform = platform
        if uom_code is not None:
            self.uom_code = uom_code
        if uom_name is not None:
            self.uom_name = uom_name
        if plc is not None:
            self.plc = plc
        if product_line is not None:
            self.product_line = product_line
        if capacity is not None:
            self.capacity = capacity
        if usage is not None:
            self.usage = usage
        if notification is not None:
            self.notification = notification

    @property
    def feature_name(self):
        """Gets the feature_name of this License.  # noqa: E501


        :return: The feature_name of this License.  # noqa: E501
        :rtype: str
        """
        return self._feature_name

    @feature_name.setter
    def feature_name(self, feature_name):
        """Sets the feature_name of this License.


        :param feature_name: The feature_name of this License.  # noqa: E501
        :type: str
        """
        if feature_name is None:
            raise ValueError("Invalid value for `feature_name`, must not be `None`")  # noqa: E501

        self._feature_name = feature_name

    @property
    def issuer(self):
        """Gets the issuer of this License.  # noqa: E501


        :return: The issuer of this License.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this License.


        :param issuer: The issuer of this License.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def issued_date(self):
        """Gets the issued_date of this License.  # noqa: E501


        :return: The issued_date of this License.  # noqa: E501
        :rtype: datetime
        """
        return self._issued_date

    @issued_date.setter
    def issued_date(self, issued_date):
        """Sets the issued_date of this License.


        :param issued_date: The issued_date of this License.  # noqa: E501
        :type: datetime
        """

        self._issued_date = issued_date

    @property
    def expiry_date(self):
        """Gets the expiry_date of this License.  # noqa: E501


        :return: The expiry_date of this License.  # noqa: E501
        :rtype: datetime
        """
        return self._expiry_date

    @expiry_date.setter
    def expiry_date(self, expiry_date):
        """Sets the expiry_date of this License.


        :param expiry_date: The expiry_date of this License.  # noqa: E501
        :type: datetime
        """

        self._expiry_date = expiry_date

    @property
    def notice(self):
        """Gets the notice of this License.  # noqa: E501


        :return: The notice of this License.  # noqa: E501
        :rtype: str
        """
        return self._notice

    @notice.setter
    def notice(self, notice):
        """Sets the notice of this License.


        :param notice: The notice of this License.  # noqa: E501
        :type: str
        """

        self._notice = notice

    @property
    def valid(self):
        """Gets the valid of this License.  # noqa: E501


        :return: The valid of this License.  # noqa: E501
        :rtype: str
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this License.


        :param valid: The valid of this License.  # noqa: E501
        :type: str
        """

        self._valid = valid

    @property
    def platform(self):
        """Gets the platform of this License.  # noqa: E501


        :return: The platform of this License.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this License.


        :param platform: The platform of this License.  # noqa: E501
        :type: str
        """

        self._platform = platform

    @property
    def uom_code(self):
        """Gets the uom_code of this License.  # noqa: E501


        :return: The uom_code of this License.  # noqa: E501
        :rtype: str
        """
        return self._uom_code

    @uom_code.setter
    def uom_code(self, uom_code):
        """Sets the uom_code of this License.


        :param uom_code: The uom_code of this License.  # noqa: E501
        :type: str
        """

        self._uom_code = uom_code

    @property
    def uom_name(self):
        """Gets the uom_name of this License.  # noqa: E501


        :return: The uom_name of this License.  # noqa: E501
        :rtype: str
        """
        return self._uom_name

    @uom_name.setter
    def uom_name(self, uom_name):
        """Sets the uom_name of this License.


        :param uom_name: The uom_name of this License.  # noqa: E501
        :type: str
        """

        self._uom_name = uom_name

    @property
    def plc(self):
        """Gets the plc of this License.  # noqa: E501


        :return: The plc of this License.  # noqa: E501
        :rtype: str
        """
        return self._plc

    @plc.setter
    def plc(self, plc):
        """Sets the plc of this License.


        :param plc: The plc of this License.  # noqa: E501
        :type: str
        """

        self._plc = plc

    @property
    def product_line(self):
        """Gets the product_line of this License.  # noqa: E501


        :return: The product_line of this License.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this License.


        :param product_line: The product_line of this License.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def capacity(self):
        """Gets the capacity of this License.  # noqa: E501

        Capacity allowed by the license. Only applicable to capacity-based license.  # noqa: E501

        :return: The capacity of this License.  # noqa: E501
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this License.

        Capacity allowed by the license. Only applicable to capacity-based license.  # noqa: E501

        :param capacity: The capacity of this License.  # noqa: E501
        :type: float
        """

        self._capacity = capacity

    @property
    def usage(self):
        """Gets the usage of this License.  # noqa: E501

        usage of the license. Only applicable to capacity-based license.  # noqa: E501

        :return: The usage of this License.  # noqa: E501
        :rtype: float
        """
        return self._usage

    @usage.setter
    def usage(self, usage):
        """Sets the usage of this License.

        usage of the license. Only applicable to capacity-based license.  # noqa: E501

        :param usage: The usage of this License.  # noqa: E501
        :type: float
        """

        self._usage = usage

    @property
    def notification(self):
        """Gets the notification of this License.  # noqa: E501

        Notification for the license. Only applicable to capacity-based license.  # noqa: E501

        :return: The notification of this License.  # noqa: E501
        :rtype: str
        """
        return self._notification

    @notification.setter
    def notification(self, notification):
        """Sets the notification of this License.

        Notification for the license. Only applicable to capacity-based license.  # noqa: E501

        :param notification: The notification of this License.  # noqa: E501
        :type: str
        """

        self._notification = notification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, License):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DeviceMigration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'source': 'str',
        'target': 'str',
        'from_cluster': 'str',
        'to_cluster': 'str',
        'start_time': 'str',
        'status': 'str',
        'percentage_done': 'int',
        'transfer_size': 'int',
        'type': 'str',
        'source_exported': 'bool',
        'target_exported': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'source': 'source',
        'target': 'target',
        'from_cluster': 'from_cluster',
        'to_cluster': 'to_cluster',
        'start_time': 'start_time',
        'status': 'status',
        'percentage_done': 'percentage_done',
        'transfer_size': 'transfer_size',
        'type': 'type',
        'source_exported': 'source_exported',
        'target_exported': 'target_exported'
    }

    def __init__(self, name=None, source=None, target=None, from_cluster=None, to_cluster=None, start_time=None, status=None, percentage_done=None, transfer_size=None, type=None, source_exported=None, target_exported=None):  # noqa: E501
        """DeviceMigration - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._source = None
        self._target = None
        self._from_cluster = None
        self._to_cluster = None
        self._start_time = None
        self._status = None
        self._percentage_done = None
        self._transfer_size = None
        self._type = None
        self._source_exported = None
        self._target_exported = None
        self.discriminator = None

        self.name = name
        if source is not None:
            self.source = source
        if target is not None:
            self.target = target
        if from_cluster is not None:
            self.from_cluster = from_cluster
        if to_cluster is not None:
            self.to_cluster = to_cluster
        if start_time is not None:
            self.start_time = start_time
        if status is not None:
            self.status = status
        if percentage_done is not None:
            self.percentage_done = percentage_done
        if transfer_size is not None:
            self.transfer_size = transfer_size
        if type is not None:
            self.type = type
        if source_exported is not None:
            self.source_exported = source_exported
        if target_exported is not None:
            self.target_exported = target_exported

    @property
    def name(self):
        """Gets the name of this DeviceMigration.  # noqa: E501


        :return: The name of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceMigration.


        :param name: The name of this DeviceMigration.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def source(self):
        """Gets the source of this DeviceMigration.  # noqa: E501


        :return: The source of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DeviceMigration.


        :param source: The source of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def target(self):
        """Gets the target of this DeviceMigration.  # noqa: E501


        :return: The target of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this DeviceMigration.


        :param target: The target of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def from_cluster(self):
        """Gets the from_cluster of this DeviceMigration.  # noqa: E501


        :return: The from_cluster of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._from_cluster

    @from_cluster.setter
    def from_cluster(self, from_cluster):
        """Sets the from_cluster of this DeviceMigration.


        :param from_cluster: The from_cluster of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._from_cluster = from_cluster

    @property
    def to_cluster(self):
        """Gets the to_cluster of this DeviceMigration.  # noqa: E501


        :return: The to_cluster of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._to_cluster

    @to_cluster.setter
    def to_cluster(self, to_cluster):
        """Sets the to_cluster of this DeviceMigration.


        :param to_cluster: The to_cluster of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._to_cluster = to_cluster

    @property
    def start_time(self):
        """Gets the start_time of this DeviceMigration.  # noqa: E501


        :return: The start_time of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this DeviceMigration.


        :param start_time: The start_time of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def status(self):
        """Gets the status of this DeviceMigration.  # noqa: E501


        :return: The status of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeviceMigration.


        :param status: The status of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def percentage_done(self):
        """Gets the percentage_done of this DeviceMigration.  # noqa: E501


        :return: The percentage_done of this DeviceMigration.  # noqa: E501
        :rtype: int
        """
        return self._percentage_done

    @percentage_done.setter
    def percentage_done(self, percentage_done):
        """Sets the percentage_done of this DeviceMigration.


        :param percentage_done: The percentage_done of this DeviceMigration.  # noqa: E501
        :type: int
        """

        self._percentage_done = percentage_done

    @property
    def transfer_size(self):
        """Gets the transfer_size of this DeviceMigration.  # noqa: E501


        :return: The transfer_size of this DeviceMigration.  # noqa: E501
        :rtype: int
        """
        return self._transfer_size

    @transfer_size.setter
    def transfer_size(self, transfer_size):
        """Sets the transfer_size of this DeviceMigration.


        :param transfer_size: The transfer_size of this DeviceMigration.  # noqa: E501
        :type: int
        """

        self._transfer_size = transfer_size

    @property
    def type(self):
        """Gets the type of this DeviceMigration.  # noqa: E501


        :return: The type of this DeviceMigration.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeviceMigration.


        :param type: The type of this DeviceMigration.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def source_exported(self):
        """Gets the source_exported of this DeviceMigration.  # noqa: E501


        :return: The source_exported of this DeviceMigration.  # noqa: E501
        :rtype: bool
        """
        return self._source_exported

    @source_exported.setter
    def source_exported(self, source_exported):
        """Sets the source_exported of this DeviceMigration.


        :param source_exported: The source_exported of this DeviceMigration.  # noqa: E501
        :type: bool
        """

        self._source_exported = source_exported

    @property
    def target_exported(self):
        """Gets the target_exported of this DeviceMigration.  # noqa: E501


        :return: The target_exported of this DeviceMigration.  # noqa: E501
        :rtype: bool
        """
        return self._target_exported

    @target_exported.setter
    def target_exported(self, target_exported):
        """Sets the target_exported of this DeviceMigration.


        :param target_exported: The target_exported of this DeviceMigration.  # noqa: E501
        :type: bool
        """

        self._target_exported = target_exported

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceMigration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    VPlex REST API

    A defnition for the next-gen VPlex API  # noqa: E501

    OpenAPI spec version: 0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class HardwarePort(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'director': 'str',
        'status': 'str',
        'address': 'str',
        'role': 'str'
    }

    attribute_map = {
        'name': 'name',
        'director': 'director',
        'status': 'status',
        'address': 'address',
        'role': 'role'
    }

    def __init__(self, name=None, director=None, status=None, address=None, role=None):  # noqa: E501
        """HardwarePort - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._director = None
        self._status = None
        self._address = None
        self._role = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if director is not None:
            self.director = director
        if status is not None:
            self.status = status
        if address is not None:
            self.address = address
        if role is not None:
            self.role = role

    @property
    def name(self):
        """Gets the name of this HardwarePort.  # noqa: E501


        :return: The name of this HardwarePort.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HardwarePort.


        :param name: The name of this HardwarePort.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def director(self):
        """Gets the director of this HardwarePort.  # noqa: E501


        :return: The director of this HardwarePort.  # noqa: E501
        :rtype: str
        """
        return self._director

    @director.setter
    def director(self, director):
        """Sets the director of this HardwarePort.


        :param director: The director of this HardwarePort.  # noqa: E501
        :type: str
        """

        self._director = director

    @property
    def status(self):
        """Gets the status of this HardwarePort.  # noqa: E501


        :return: The status of this HardwarePort.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this HardwarePort.


        :param status: The status of this HardwarePort.  # noqa: E501
        :type: str
        """
        allowed_values = ["up", "down", "no-link"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def address(self):
        """Gets the address of this HardwarePort.  # noqa: E501


        :return: The address of this HardwarePort.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this HardwarePort.


        :param address: The address of this HardwarePort.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def role(self):
        """Gets the role of this HardwarePort.  # noqa: E501


        :return: The role of this HardwarePort.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this HardwarePort.


        :param role: The role of this HardwarePort.  # noqa: E501
        :type: str
        """
        allowed_values = ["front-end", "back-end", "local-com", "wan-com", "management", "inter-director-communication"]  # noqa: E501
        if role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}"  # noqa: E501
                .format(role, allowed_values)
            )

        self._role = role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HardwarePort):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
